Module request

Module request 

Re-exports

pub use alloc_mod::*;alloc

Modules

alloc_modalloc

Structs

FilePathTooLarge
PutRequest
StaticPutRequestCacher
This is a put request cache structure which can be used to cache ReadablePutRequests without requiring run-time allocation. The user must specify the static buffer sizes used to store TLVs or list of TLVs.
StaticPutRequestFields
TlvWithInvalidType

Traits

ReadablePutRequest
This trait is an abstraction for different Put Request structures which can be used by Put Request consumers.

Functions

generic_path_checks
generic_tlv_list_type_check